@@ -134,6 +134,7 @@ def parse_args(required_config_keys):
     -d,--discover   Run in discover mode
     -p,--properties Properties file: DEPRECATED, please use --catalog instead
     --catalog       Catalog file
+    --dev     Runs the tap in dev mode
 
     Returns the parsed args object from argparse. For each argument that
     point to JSON files (config, state, properties), we will automatically
@@ -163,6 +164,11 @@ def parse_args(required_config_keys):
         action='store_true',
         help='Do schema discovery')
 
+    parser.add_argument(
+        '--dev',
+        action='store_true',
+        help='Runs tap in dev mode')
+
     args = parser.parse_args()
     if args.config:
         setattr(args, 'config_path', args.config)
@@ -228,7 +234,8 @@ def handle_top_exception(logger):
             try:
                 return fnc(*args, **kwargs)
             except Exception as exc:
-                logger.critical(exc)
+                for line in str(exc).splitlines():
+                    logger.critical(line)
                 raise
         return wrapped
     return decorator
